@@ -674,3 +674,7 @@ def _set_seq_gaps_subopt(residues, subopt_pos):
                     raise modeller.FileFormatError("suboptimal alignment " + \
                               "file SEQ1 and SEQ2 indices should be sequential")
                 pos_n += 1
+
+
+# Modeller 10 compatibility
+Alignment = alignment
