@@ -16,3 +16,7 @@ class allhmodel(automodel):
                            library_schedule, csrfile, inifile, assess_methods)
         # Modeling won't work unless we read/write hydrogen atoms!
         self.env.io.hydrogen = True
+
+
+# Modeller 10 compatibility
+AllHModel = allhmodel
