@@ -11,6 +11,7 @@ class io_data(modobject):
     convert_modres = True
     __atom_files_directory = ['']
     __modpt = None
+    __free_func = _modeller.mod_io_data_free
 
     def __init__(self, copy=None, **kwargs):
         self.__modpt = _modeller.mod_io_data_new()
@@ -32,7 +33,7 @@ class io_data(modobject):
 
     def __del__(self):
         if self.__modpt:
-            _modeller.mod_io_data_free(self.__modpt)
+            self.__free_func(self.__modpt)
 
     def __get_atfil(self):
         return self.__atom_files_directory
@@ -62,3 +63,7 @@ class io_data(modobject):
                                     doc="List of paths to search " + \
                                         "for atom files")
     modpt = property(__get_modpt)
+
+
+# Modeller 10 compatibility
+IOData = io_data
