@@ -481,3 +481,7 @@ For example, replace 'generate_topology(aln, sequence="foo")' with
     angles = property(__get_angles, doc="All defined angles")
     dihedrals = property(__get_dihedrals, doc="All defined dihedrals")
     impropers = property(__get_impropers, doc="All defined impropers")
+
+
+# Modeller 10 compatibility
+Model = model
